@@ -5,6 +5,7 @@
 
 #define N 16
 
+__attribute__ ((noinline))
 int main1 ()
 {
   int i;
@@ -35,3 +36,4 @@ int main (void)
 }
 
 /* { dg-final { scan-tree-dump-times "vectorized 1 loops" 1 "vect" { xfail *-*-* } } } */
+/* { dg-final { cleanup-tree-dump "vect" } } */
